@@ -6,3 +6,6 @@ def as_list(func):
     def wrapped(*args, **kwargs):
         return list(func(*args, **kwargs))
     return wrapped
+
+def sanitize_email(email):
+    return email.replace("_", r"\_")
